%global sover   3

%ifarch x86_64
%bcond_without vmaf
%endif
%bcond_without jpegxl

Summary:        Royalty-free next-generation video format
Name:           aom
Version:        3.9.0
Release:        2%{?dist}
License:        BSD-3-Clause
URL:            http://aomedia.org/
Source0:        https://aomedia.googlesource.com/%{name}/+archive/v%{version}.tar.gz #/%{name}-v%{version}.tar.gz


BuildRequires:  gcc gcc-c++ cmake3 git doxygen yasm
BuildRequires:  perl-interpreter perl(Getopt::Long) python3-devel
%if %{with vmaf}
BuildRequires:  pkgconfig(libvmaf)
%endif
%if %{with jpegxl}
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  pkgconfig(libhwy)
%endif

Requires:       libaom = %{version}-%{release}
Provides:       av1 = %{version}-%{release}

%description
The Alliance for Open Media’s focus is to deliver a next-generation video format that is:
 - Interoperable and open;
 - Optimized for the Internet;
 - Scalable to any modern device at any bandwidth;
 - Designed with a low computational footprint and optimized for hardware;
 - Capable of consistent, highest-quality, real-time video delivery; and
 - Flexible for both commercial and non-commercial content, including user-generated content.

This package contains the reference encoder and decoder.


%package -n libaom
Summary:        Library files for aom

%description -n libaom
Library files for aom, the royalty-free next-generation video format.


%package -n libaom-devel
Summary:        Development files for aom
Requires:       libaom = %{version}-%{release}

%description -n libaom-devel
Development files for aom, the royalty-free next-generation video format.


%prep
%autosetup -p1 -c %{name}-%{version}
sed -i 's|set(aom_version "")|set(aom_version "v%{version}")|' build/cmake/version.cmake
sed -i "s|GENERATE_LATEX         = YES|GENERATE_LATEX         = NO|" libs.doxy_template


%build
%ifarch %{arm}
%global optflags %{__global_compiler_flags} -march=armv7-a -mfpu=neon -mtune=cortex-a8 -mabi=aapcs-linux -mfloat-abi=hard
%endif

%cmake3 -DENABLE_CCACHE=1 \
        -DCMAKE_SKIP_RPATH=1 \
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \
        -DCONFIG_WEBM_IO=1 \
        -DENABLE_DOCS=1 \
        -DENABLE_TESTS=0 \
        -DCONFIG_ANALYZER=0 \
        -DBUILD_SHARED_LIBS=1 \
%if %{with vmaf}
        -DCONFIG_TUNE_VMAF=1 \
%endif
%if %{with jpegxl}
        -DCONFIG_TUNE_BUTTERAUGLI=1 \
%endif
        %{nil}
%cmake3_build


%install
%cmake3_install
rm -rvf %{buildroot}%{_libdir}/libaom.a


%files
%license LICENSE PATENTS
%doc AUTHORS CHANGELOG README.md
%{_bindir}/aomdec
%{_bindir}/aomenc


%files -n libaom
%license LICENSE PATENTS
%{_libdir}/libaom.so.%{sover}*


%files -n libaom-devel
%doc %{_vpath_builddir}/docs/html/
%{_libdir}/libaom.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.9.0-2
- Rebuilt for loongarch release

* Mon Jul 29 2024 Upgrade Robot <upbot@opencloudos.tech> - 3.9.0-1
- Upgrade to version 3.9.0
- fix CVE-2024-5171

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 rockerzhu <rockerzhu@tencent.com> - 3.6.0-1
- Initial build
